"""
Pydantic schema for FooterSmall02 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/footers/footer-small-02.tsx
Component Path: marketing/footers/footer-small-02
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class FooterSmall02Props(JSONFieldSchema):
    """Props for FooterSmall02"""

    brand_name: str | None = Field(default=None, alias="brandName")
    copyright_text: str | None = Field(default=None, alias="copyrightText")
    logo_url: str | None = Field(default=None, alias="logoUrl")
